{%- from "ironic/map.jinja" import api,conductor with context %}
{%- if api.get("enabled", False) %}
  {%- set ironic, service_name = api, 'api' %}
{%- elif conductor.get("enabled", False) %}
  {%- set ironic, service_name = conductor, 'conductor' %}
{%- endif %}

include:
  - ironic._ssl.mysql
  - ironic._ssl.rabbitmq
{%- if api.get("enabled", False) %}
  - ironic.api
{%- elif conductor.get("enabled", False) %}
  - ironic.conductor
{%- endif %}

ironic_common_pkgs:
  pkg.installed:
    - name: 'ironic-common'
    - install_recommends: False
    - require_in:
      - sls: ironic._ssl.mysql
      - sls: ironic._ssl.rabbitmq

/etc/ironic/ironic.conf:
  file.managed:
  - source: salt://ironic/files/{{ ironic.version }}/ironic.conf
  - template: jinja
  - require:
    - pkg: ironic_common_pkgs
    - sls: ironic._ssl.mysql
    - sls: ironic._ssl.rabbitmq

{% if ironic.logging.log_appender %}
ironic_general_logging_conf:
  file.managed:
    - name: /etc/ironic/logging.conf
    - source: salt://oslo_templates/files/logging/_logging.conf
    - template: jinja
    - user: ironic
    - group: ironic
    - defaults:
        service_name: ironic
        _data: {{ ironic.logging }}
    - watch_in:
      - service: {{ ironic.service }}
ironic_log_file:
  file.managed:
    - name: /var/log/ironic/ironic.log
    - user: ironic
    - group: ironic
    - watch_in:
      - service: {{ ironic.service }}
{% endif %}

{%- if ironic.get('concurrency', {}).lock_path is defined %}
ironic_{{ service_name }}_lock_path_{{ ironic.concurrency.lock_path }}:
  file.directory:
  - name: {{ ironic.concurrency.lock_path }}
  - user: ironic
  - group: ironic
  - mode: 750
  - makedirs: True
  - require:
    - pkg: ironic_common_pkgs
  - require_in:
    - service: {{ ironic.service }}
{%- endif %}
